# Introduction

This document will guide you in setting up the Accelerator in a bare metal or virtual machine environment. Virtual machines may either run locally, or in a cloud service such as AWS or Azure.

After completing the setup, you will have an environment suitable for development, demo, and runtime uses. 

# Deployment Environment

Running the Accelerator in a production environment will require a detailed analysis of network size and anticipated volumes. This is out of scope for this document and TIBCO Professional Services Group should be engaged in such an exercise. For the purposes of getting the demo up and running, the following are guideline minimum recommended configurations.

For **bare metal deployment**, the minimum configuration is:

<table>
    <tr>
        <th style="text-align:left;">Operating System</th>
        <td>Windows 10/2019 64-bit</td>
    </tr>
    <tr>
        <th style="text-align:left;">Database</th>
        <td>SQL Server 2019 Standard</td>
    </tr>
    <tr>
        <th style="text-align:left;">CPU</th>
        <td>Minimum 8 cores, more will give better performance</td>
    </tr>
    <tr>
        <th style="text-align:left;">Memory</th>
        <td>Minimum 24GB, more will give better performance</td>
    </tr>
    <tr>
        <th style="text-align:left;">Disk</th>
        <td>Minimum 70GB</td>
    </tr>
</table>

For **AWS deployment**, the minimum configuration is:

<table>
    <tr>
        <th style="text-align:left;">Operating System</th>
        <td>Microsoft Windows Server 2019/SQL Server 2019 Standard</td>
    </tr>
    <tr>
        <th style="text-align:left;">CPU</th>
        <td>m4.2xlarge or m5ad.2xlarge<br/><br/>
            8 vCPUs, 32GB RAM
        </td>
    </tr>
    <tr>
        <th style="text-align:left;">Storage</th>
        <td>70GB</td>
    </tr>
    <tr>
        <th style="text-align:left;">Security</th>
        <td>Open port 10085 for operations dashboard</td>
    </tr>
</table>

For other types of virtual machines or cloud services, these configurations can be used as guidelines.

# Software Dependencies

The following runtime software are required to run the Accelerator. The following TIBCO components are mandatory for all installation types:

Software | Source
---------|-------
TIBCO Spotfire® Desktop 11.7.0 | [TIBCO eDelivery](https://edelivery.tibco.com/)
TIBCO Streaming 10.6.2 | [TIBCO eDelivery](https://edelivery.tibco.com/)
TIBCO Artifact Management Server 1.6.2 | [TIBCO eDelivery](https://edelivery.tibco.com/)

Note that the versions specified here were current as of date of release of the Accelerator on TIBCO Community. In most cases using later versions will work ok, but the installation script will need to be adjusted and code will need to be recompiled on the newer versions.

# Distribution

The Accelerator is distributed as source via Github, or as a source ZIP file downloaded from TIBCO Community. The build script is written assuming the source ZIP will be provided.

Once the ZIP file is extracted, the output directory structure will be identical to the Github repository.

The source ZIP should be extracted to the path **C:\workspace** which will create a **Grid** directory at that location. If downloading from Github, the contents of the repository should be placed in the path **C:\workspace\Grid**. This location will be referred to as  **&lt;WORKSPACE_HOME&gt;** through the remainder of this document. It is possible to use a different location, but the default configuration and scripts will require modification to support this.

The following directory structure will be present under **&lt;WORKSPACE_HOME&gt;**:

Directory | Description | Role
----------|-------------|-----
data | Configuration files and reference data | Run
doc | Documentation | Dev/Run
scripts | Scripts used to start Accelerator components | Run
src | Source code for all the Accelerator components | Dev/Run
test | Testcases and sample data | Run

# Setup 

To setup the environment a Windows build script is provided at **&lt;WORKSPACE_HOME&gt;/scripts/installation/win/accelerator-install.bat**. To build on other operating systems or to execute a manual build, refer to this batch script for the steps required.

## Microsoft .NET Preparation

Download and install .NET Framework 4.8 before running the install script.  

## Python Preparation

Download and install Python 3.9 or greater before running the install script. The Event Manager is built assuming this will be located at **C:\python\python39**. Other paths are possible but Predict.sbapp in the project will need updating.

Python must have the following packages installed:

* tensorflow
* numpy
* pandas
* pickle
* sklearn

## Microsoft Visual C++ Redistributable Preparation

Tensorflow requires the latest VC++ installation from Microsoft. Download and install this before running the install script.

## Downloads

1.	Create a directory **C:\installation\packages**. It is possible to use other directory names, but the install script will need to be modified to support this.
2.	Download the Accelerator source package from TIBCO Community. Place this in the **C:\installation\packages** directory, unextracted.

Software | Filename | Location
---------|----------|---------
Grid Monitoring Accelerator 1.0.0 | GridMonitoring_1.0.0.zip | [TIBCO Community](https://community.tibco.com/modules/grid-monitoring-accelerator)

3.	From the Accelerator source package extract only **scripts/installation/win/installation/accelerator-install.bat** and place in **C:\installation**. Your directory structure should look like this:

![](./images/installation-file-explorer.png)

4.	Download the required TIBCO software from eDelivery. Place each of these in the **C:\installation\packages** directory, unextracted.

Software | Filename | Location
---------|----------|---------
Spotfire® Desktop 11.7.0 | TIB_spd_11.7.0_shared_computer_win.zip | [TIBCO eDelivery](https://edelivery.tibco.com/)
TIBCO Streaming 10.6.2 | TIB_str_10.6.2_win_x86_64.msi | [TIBCO eDelivery](https://edelivery.tibco.com/)
TIBCO Artifact Management Server 1.6.2 | TIB_str_ams_1.6.2_win_x86_64.msi | [TIBCO eDelivery](https://edelivery.tibco.com/)

## Install

1.	Open a command prompt and change to the directory **C:\installation**. The install script MUST be run as Administrator so ensure that the command prompt is opened with Administrator privileges.
2.	Run the install script using the following command:
```
accelerator-install.bat
```
3.	The script should run to completion without errors, but will take some time to complete.

The steps the script will execute are:
1. Extract the Accelerator distribution into &lt;WORKSPACE_HOME&gt;
1. Install Spotfire® Desktop to TIBCO_HOME _(c:/tibco)_
1. Install TIBCO Streaming to TIBCO_HOME _(c:/tibco)_
1. Install TIBCO Artifact Management Server to TIBCO_HOME _(c:/tibco)_
1. Build TIBCO Streaming fragments and applications

# Build Source

The installation script will automatically build the TIBCO Streaming fragments and applications. However, if you make changes to the source they will need to be rebuilt. To do this open a **StreamBase Command Prompt** in the appropriate location:

Component | Source Home
----------|------------
TIBCO Streaming | **&lt;WORKSPACE_HOME&gt;/src/sb/grid-main**

Build any of these components using this command:

```
mvn clean install
```

# Starting Up and Shutting Down

Scripts to start the various components are located in **&lt;WORKSPACE_HOME&gt;/scripts/win**. The scripts for starting TIBCO Live Datamart and Event Manager all accept a parameter to indicate what action to execute:

* **install** – install and start a node
* **start** – start a node that has been installed and node coordinator is running
* **restart** – start a node that has been installed but node coordinator is not running
* **stop** – stop a node
* **remove** – stop and remove a node
* **terminate** – stops the node coordinator
* **showlog** – display log file

Normally to start an application you use the install command, and to stop it use the remove command.

## Starting Up

Before trying to start the components ensure that there is a working directory prepared and available. In the default Accelerator scripts this will be located at **&lt;WORKSPACE_HOME&gt;/../tmp/nodes**.

If the components have been previously started, ensure the working directory for the nodes has been cleared out. If nodes have been started previously and were not cleanly removed, then this directory will have node working files in it and trying to install again will result in a failure.

For example, in the figure below, the directory **Grid** represents **&lt;WORKSPACE_HOME&gt;** and under **tmp/nodes** there are two directories, one for each of Dashboard and Event Manager. In order to start from a clean system, these sub-directories should be removed.

When trying to remove directories, if the nodes have been started but the machine not rebooted then there may be processes locking the files. Either reboot the machine or stop any DTMEngine.exe processes present on the machine using Task Manager.

![](./images/workspace-home.png)

Start the components in the following order. All scripts can be executed in parallel, but TIBCO Artifact Management Server must be running before the Event Manager tries to load decision tables and models. Due to the latency involved in starting, normally it will be fine to start in parallel. 

**Do not forget to include the install parameter for each command.**

Step | Component | Script | Remarks
-----|-----------|--------|--------
1.| Live Datamart | <nobr>`01-lv-cmd.bat install`</nobr> | 
2.| Event Manager | <nobr>`02-em-cmd.bat install`</nobr> | 

The LDM node will be ready when you see something like the following in the console. This is not a complete record of what will be logged, but only key entries that will be observed:

```
```

The Event Manager node will be ready once you see the following:

```
```


## Shutting Down

Its very important to stop the TIBCO Streaming engines correctly, otherwise issues may arise with leftover nodes and they will fail to start correctly the next time. Stop the components in any order. All scripts can be executed in parallel. 

**Do not forget to include the remove parameter for each command.**

Step | Component | Script | Remarks
-----|-----------|--------|--------
1.| Live Datamart | CTRL-C and then <nobr>`01-lv-cmd.bat remove`</nobr> | 
2.| Event Manager | CTRL-C and then <nobr>`02-em-cmd.bat remove`</nobr> | 

# Demo Start And Control

## Access the User Interface

## Accelerator Dashboard

Open the Accelerator Dashboard using Spotfire® Desktop. The DXP is located at **&lt;WORKSPACE_HOME&gt;/src/spotfire/grid.dxp**.

![](./images/dashboard-main-trust.png)

On first load the Simulation Control in the bottom left corner will not render correctly due to an included JavaScript. Select the Manage Trust option and select Trust All.

![](./images/dashboard-main.png)

Once trusted then buttons should appear. 

Start the simulation by clicking the **Start** button, and clear the LDM tables by clicking the **Clear** button. Once running, options to **Pause** and **Stop** the simulation are available. The rate at which data is processed can be adjusted using the slider and then click the **Scale** button.

![](./images/dashboard-session-1.png)

