@echo off
setlocal

rem ================================================================================
rem Environment variables
rem Change these

set SF_DESKTOP_VERSION=11.8.0

set SB_AMS_VERSION=1.6.2
set SB_VERSION=10.6.2
set SB_PATH_VERSION=10.6

set WORKSPACE_HOME=c:/workspace
set ACCELERATOR_VERSION=1.0.0
set ACCELERATOR_PACKAGE=GridMonitoring_%ACCELERATOR_VERSION%.zip
set ACCELERATOR_HOME=%WORKSPACE_HOME%/Grid
set ACCELERATOR_NAME=Grid Monitoring Accelerator

rem Do not change these

set PACKAGE_DIR=c:/installation/packages
set TEMP_DIR=c:/installation/temp
set TIBCO_HOME_DIR=c:/tibco

set SB_TARGET=%TIBCO_HOME_DIR%/sb-cep/%SB_PATH_VERSION%
set SF_DESKTOP_INSTALL_TARGET=%TIBCO_HOME_DIR%/tsd/%SF_DESKTOP_VERSION%
set MAVEN_REPOSITORY=%USERPROFILE:\=/%/.m2/repository
set JAVA_HOME=%SB_TARGET%/jdk

FOR /F "usebackq" %%i IN (`hostname`) DO SET HOSTNAME=%%i


rem ================================================================================
rem Execute installation

call :install_accelerator
call :install_spotfire_desktop
call :install_streaming
call :install_streaming_ams
call :build_accelerator
exit /B %ERRORLEVEL%


rem ================================================================================
rem Functions

rem Prepare the temporary directory
:prepare_temp
if exist "%TEMP_DIR%" rd /q /s "%TEMP_DIR%"
if not exist "%TEMP_DIR%" mkdir "%TEMP_DIR%"
exit /B 0


rem ================================================================================
rem Install TIBCO Spotfire Desktop

:install_spotfire_desktop
echo ====================================================================================================
set SF_DESKTOP_INSTALLER=TIB_spd_%SF_DESKTOP_VERSION%_shared_computer_win.zip

echo Installing TIBCO Spotfire Desktop %SF_DESKTOP_VERSION% to default install location
call :prepare_temp
tar -xf %PACKAGE_DIR%/%SF_DESKTOP_INSTALLER% -C %TEMP_DIR%
"%TEMP_DIR%/Products/TIBCO Spotfire Desktop Installer/setup-machine-%SF_DESKTOP_VERSION%.exe" /i /s /l*v %TEMP_DIR%\TSD_install.txt ALLUSERS=1 INSTALLDIR=%SF_DESKTOP_INSTALL_TARGET:/=\%
echo.
exit /B 0


rem ================================================================================
rem Install TIBCO Streaming

:install_streaming
echo ====================================================================================================
set SB_INSTALLER=TIB_str_%SB_VERSION%_win_x86_64.msi
set SB_INSTALL_TARGET=%TIBCO_HOME_DIR%

echo Installing TIBCO Streaming %SB_VERSION% to %SB_INSTALL_TARGET%
msiexec /quiet /i %PACKAGE_DIR:/=\%\%SB_INSTALLER% TIBCO_HOME="%TIBCO_HOME_DIR:/=\%"

echo Install TIBCO Streaming components into local Maven repository
if not exist "%MAVEN_REPOSITORY%" mkdir "%MAVEN_REPOSITORY%"
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-maven-build-sdk.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-platform-sdk-windowsx64.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-product-artifacts-repo.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-product-artifacts-repo-offline-projects.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-runtime-sdk.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-runtime-sdk-offline-projects.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-kits-tibco-versions-sdk.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-lvweb-sdk.zip -C %MAVEN_REPOSITORY%
tar -xf %SB_TARGET%/sdk/maven/product-artifact/str-%SB_VERSION%-platform-sdk-linuxx86_64-artifacts.zip -C %MAVEN_REPOSITORY%
echo.
exit /B 0


rem ================================================================================
rem Install TIBCO Streaming AMS

:install_streaming_ams
echo ====================================================================================================
set SB_AMS_INSTALLER=TIB_str_ams_%SB_AMS_VERSION%_win_x86_64.msi
set SB_AMS_INSTALL_TARGET=%TIBCO_HOME_DIR%

echo Installing TIBCO Streaming Artifact Management Server %SB_AMS_VERSION% to %SB_AMS_INSTALL_TARGET%
msiexec /quiet /i %PACKAGE_DIR:/=\%\%SB_AMS_INSTALLER% TIBCO_HOME="%SB_AMS_INSTALL_TARGET:/=\%"
echo.
exit /B 0


rem ================================================================================
rem Install Accelerator

:install_accelerator
echo ====================================================================================================
echo Installing %ACCELERATOR_NAME% %ACCELERATOR_VERSION% to %WORKSPACE_HOME%
if not exist "%WORKSPACE_HOME%" mkdir "%WORKSPACE_HOME%"
tar -xf %PACKAGE_DIR%/%ACCELERATOR_PACKAGE% -C %WORKSPACE_HOME%
echo.
exit /B 0


:build_accelerator
echo ====================================================================================================
echo Building %ACCELERATOR_NAME% %ACCELERATOR_VERSION% to %WORKSPACE_HOME%

echo Building TIBCO Streaming fragments and applications
call %SB_TARGET%/sdk/mvn/bin/mvn -f %ACCELERATOR_HOME%/src/sb/grid-main clean install
echo.
exit /B 0
