model_path = 'C:/workspace/Grid/src/sb/grid-main/grid-fragments/grid-fragment-eventmanager/src/main/resources/python/models/'
input_data = 'test_data.pkl'

import time
import tensorflow as tf
import numpy as np
import pandas as pd
import pickle
from sklearn.preprocessing import LabelEncoder, OneHotEncoder, OrdinalEncoder

# ##########################################################################################
# START LOADER

scaler = pickle.load(open(model_path + 'scaler.pkl','rb'))
lstm_autoencoder_model = tf.keras.models.load_model(model_path + 'best_model.h5')
training_data = pickle.load(open(model_path + 'training_data.pkl','rb'))

def encode_column(data, training_data, this_encoder, reshape=False):
    #print(data.name)
    training_data = training_data[data.name].values
    data = data.values
    if reshape == True:
        training_data = training_data.reshape(-1,1)
        data = data.reshape(-1,1)

    this_encoder = this_encoder.fit(training_data)
    encoded_data = this_encoder.transform(data)
    if encoded_data.ndim == 2:
        encoded_data = encoded_data.reshape(len(encoded_data))
    return encoded_data

# Generated training sequences for use in the model
def create_sequences(data, lookback):
    output = []
    for i in range(len(data) - lookback + 1):
        output.append(data[i : (i + lookback), :])

    return np.stack(output)

# END LOADER
# ##########################################################################################

start = time.time()
test_df = pickle.load(open(input_data, 'rb'))

# ##########################################################################################
# START PREDICTOR

## HARD CODED VALUES FROM MODEL BUILD
text_encoding_method = "ordinal"
history_size = 3
#model_path = "c:/temp/"

columns_to_use = ['hostname','availableDiskInMB','cpuCoreCount','cpuIdString','cpuMHz','cpuNo','cpuSocketCount','cpuThreadCount','cpuTotal','freeDiskInMB',\
                  'freeMemInKB','os','osName','osUsername','osVersion','totalMemInKB','eventClass','eventType','managerHostName','driverName','rescheduledCount']

test_df = pd.DataFrame.from_dict(test_df)
test_df = test_df.loc[:,columns_to_use]

## columns that need converted
float_cols = ['availableDiskInMB', 'cpuMHz', 'cpuTotal', 'freeDiskInMB', 'freeMemInKB', 'totalMemInKB']
int_cols = ['cpuCoreCount','cpuNo', 'cpuSocketCount', 'cpuThreadCount']
string_cols = list(set(test_df.columns) - set(int_cols + float_cols))

## convert types as SB passes everything as string if null data
test_df[float_cols] = test_df[float_cols].astype('float64')
test_df[int_cols] = test_df[int_cols].astype('Int32')
test_df[string_cols] = test_df[string_cols].astype('object')

## drop date columns and useless columns
test_df = test_df.apply(lambda x: x.fillna('null_value') if x.dtype == 'object' else x.fillna(0))

## encode strings as required
encoder_reshape = True
if text_encoding_method == "label":
    this_encoder = LabelEncoder()
    encoder_reshape = False
    test_df = test_df.apply(lambda x: encode_column(x, training_data, this_encoder, encoder_reshape) if x.dtype == 'object' else x)
elif text_encoding_method == "onehot":
    this_encoder = OneHotEncoder(handle_unknown='ignore')
    #default text encoding method is one-hot
    #one_hot_encoder_predictors.fit(pd.DataFrame(fit_data[categorical_vars]))
    #encode_categorical_data = pd.DataFrame(one_hot_encoder_predictors.transform(pd.DataFrame(transform_data[categorical_vars])), index=transform_data.index)
    #transform_data = pd.concat([transform_data.drop(categorical_vars, axis=1), encode_categorical_data], axis=1)
elif text_encoding_method == "ordinal":
    this_encoder = OrdinalEncoder(handle_unknown='use_encoded_value', unknown_value=-1)
    test_df = test_df.apply(lambda x: encode_column(x, training_data, this_encoder, encoder_reshape) if x.dtype == 'object' else x)

## get df values
values = test_df.values

## ensure all data is float
dataset = values.astype('float64')
n_features = dataset.shape[1]

## Scale data
X_scaled = scaler.transform(dataset)

# Temporalize the data
X_scaled = create_sequences(X_scaled, lookback=history_size)

## Now load best model saved during learning
x_predictions = lstm_autoencoder_model.predict(X_scaled)
loss_mae = float(np.mean(np.abs(X_scaled - x_predictions)))

# END PREDICTOR
# ##########################################################################################

print(loss_mae)
print((time.time() - start) * 1000)