/*
* Copyright © 2019-2022. TIBCO Software Inc.
* This file is subject to the license terms contained
* in the license file that is distributed with this file.
*/
package com.tibco.accelerators.operators.file.render;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import com.streambase.sb.ByteArrayView;
import com.streambase.sb.CompleteDataType;
import com.streambase.sb.Function;
import com.streambase.sb.Schema;
import com.streambase.sb.Timestamp;
import com.streambase.sb.Tuple;
import com.streambase.sb.Tuple.TupleFormatter;

public class TupleToCsvRenderer {
	
	public String renderTupleToHeader(Tuple tuple, boolean passthrough, String fieldDelimiter) {
		Schema schema = tuple.getSchema();
		
		List<String> elements = new ArrayList<String>();			
		for(int idx = 0; idx < schema.getFieldCount(); idx++) {
			Schema.Field f = schema.getField(idx);
			if(passthrough == true && f.getName().equals("passthrough"))
				continue;
			elements.add(f.getName());
		}
		if(elements.size() > 0) {
			StringBuffer sb = new StringBuffer();
			sb.append(elements.get(0));
			for(int idx = 1; idx < elements.size(); idx++) {
				sb.append(fieldDelimiter);
				sb.append(elements.get(idx));
			}

			return sb.toString();
		}				
		
		return null;
	}
	
	public String renderTupleToLine(Tuple tuple, boolean passthrough, String fieldDelimiter, 
			String timestampFormat, boolean nullAsEmpty, String nullValue, String charsetName) {
		Schema schema = tuple.getSchema();

		List<String> elements = new ArrayList<String>();			
		for(int idx = 0; idx < schema.getFieldCount(); idx++) {
			Schema.Field f = schema.getField(idx);
			if(passthrough == true && f.getName().equals("passthrough"))
				continue;
			elements.add(tuple.getFieldAsString(f, new TupleToStringFormatter(timestampFormat, nullAsEmpty, nullValue)));
		}
		if(elements.size() > 0) {
			StringBuffer sb = new StringBuffer();
			sb.append(elements.get(0));
			for(int idx = 1; idx < elements.size(); idx++) {
				sb.append(fieldDelimiter);
				sb.append(elements.get(idx));
			}
			
			return sb.toString();
		}
		
		return null;
	}
	
	private class TupleToStringFormatter implements TupleFormatter {
		private SimpleDateFormat format = null;
		private boolean nullAsEmpty = true;
		private String nullValue = null;
		
		public TupleToStringFormatter(String timestampFormat, boolean nullAsEmpty, String nullValue) {
			this.format = new SimpleDateFormat(timestampFormat);
			this.nullAsEmpty = nullAsEmpty;
			this.nullValue = nullValue;
		}

		private String getNullVal() {
			if(this.nullAsEmpty == true)
				return "";
			else
				return this.nullValue;
		}
		
		@Override
		public CharSequence formatBlob(ByteArrayView blob) {
			return null;
		}

		@Override
		public CharSequence formatBool(Boolean b) {
			if(b == null) 
				return this.getNullVal();
			return b.toString();
		}

		@Override
		public CharSequence formatDouble(Double d) {
			if(d == null) 
				return this.getNullVal();
			return d.toString();
		}

		@Override
		public CharSequence formatFunction(Function f) {
			return null;
		}

		@Override
		public CharSequence formatInt(Integer i) {
			if(i == null)
				return this.getNullVal();
			return i.toString();
		}

		@Override
		public CharSequence formatList(CompleteDataType elementType, List<?> l) {
			return null;
		}

		@Override
		public CharSequence formatLong(Long l) {
			if(l == null)
				return this.getNullVal();
			return l.toString();
		}

		@Override
		public CharSequence formatString(String s) {
			if(s == null)
				return this.getNullVal();
			return s.toString();
		}

		@Override
		public CharSequence formatTimestamp(Timestamp t) {
			if(t == null)
				return this.getNullVal();
			return this.format.format(t.toDate());
		}

		@Override
		public CharSequence formatTuple(Tuple t) {
			return null;
		}
		
	}
	
}
